# Copyright (c) 2020-present, The Johann Plugin Example Authors. All Rights Reserved.
# Use of this source code is governed by a BSD-3-clause license that can
# be found in the LICENSE file. See the AUTHORS file for names of contributors.

__version__ = "0.1.0-alpha"

import johann_plugin_example.tasks
from johann_plugin_example import config as example_config
